@@ -22,13 +22,13 @@
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QIcon>
-#include <QDebug>
+#include "konqdebug.h"
 
 #include <KIO/FavIconRequestJob>
 #include <kio/global.h>
 #include <kprotocolinfo.h>
 #include <kconfiggroup.h>
-#include <kiconloader.h>
+#include <KIconLoader>
 
 class KonqPixmapProviderSingleton
 {
